<?php

namespace Drupal\user_approval_dashboard\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\user\Entity\User;

/**
 * Class UserApprovalForm.
 */
class UserApprovalForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_approval_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['message'] = [
      '#markup' => '<div class="approve">Are you sure to approve this account? If so, Click approve.</div>',
    ];
    $form['uad'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['uad-container'],
      ],
    ];
    $form['uad']['cancel'] = [
      '#type' => 'button',
      '#value' => $this->t('Cancel'),
      '#attributes' => [
        'data-dismiss' => ['modal'],
        'class' => ['uad-approve'],
      ],
    ];
    $form['uad']['submit'] = [
      '#type' => 'submit',
      '#attributes' => [
        'class' => ['uad-approve'],
      ],
      '#value' => $this->t('Approve'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $uid = \Drupal::request()->get('id');
    if ($uid && is_numeric($uid)) {
      $user = User::load($uid);
      if (is_object($user)) {
        $user->activate();
        $user->save();
        $message = t('An email has been succesfully sent to the following account.');
        \Drupal::messenger()->addStatus($message);
        $url = Url::fromRoute('view.dashboard.user_dashboard');
        // After activating the user, redirect to the dashboard.
        $form_state->setRedirectUrl($url);
      }
    }
  }

}
